ZirconCrashReason

Enum ZirconCrashReason 

#[repr(u32)]
pub enum ZirconCrashReason { Invalid = 0, Unknown = 1, NoCrash = 2, Oom = 3, Panic = 4, SoftwareWatchdog = 5, UserspaceRootJobTermination = 6, }
TODO(https://fxbug.dev/534467534): For now, these values are copied from zircon/system/public/zircon/boot/crash-reason.h.

Variants



Invalid = 0

0 is reserved for “Invalid”. It will never be used by a functioning crash-logger.



Unknown = 1

“Unknown” indicates that the system does not know the reason for a recent crash. The primary use of this reason is to be something which can be left in the crashlog in case the system spontaneously reboots without a chance to gracefully finalize the log, perhaps because of something like a hardware watchdog timer.



NoCrash = 2

“No Crash” indicates that the system deliberately rebooted in an orderly fashion. No crash occurred.



Oom = 3

“OOM” indicates a crash triggered by the system because of an unrecoverable out-of-memory situation.



Panic = 4

“Panic” indicates a crash triggered by the system because of an unrecoverable kernel panic situation.



SoftwareWatchdog = 5

“Software watchdog” indicates a crash triggered by a kernel level software watchdog construct. Note that this is distinct from a hardware based WDT. If the system reboots because of a hardware watchdog, it will have no chance to record the reboot reason, and the crashlog will indicate “unknown”. The HW reboot reason may be known, but only if the bootloader reports it to us.



UserspaceRootJobTermination = 6

“Userspace root job termination” indicates a crash triggered by the system because it detected the termination of the userspace root job, most likely because one of its critical processes crashed.